@@ -4,7 +4,7 @@ class TSQL::AST::SQLWhileStatement extends TSQL::AST::SQLStatement {
 
 use TSQL::AST::SQLStatement;
 use TSQL::AST::SQLConditionalExpression;
-use TSQL::AST::SQLStatementBlock;
+#use TSQL::AST::SQLStatementBlock;
 
 has 'condition' => (
       is  => 'rw',
@@ -19,9 +19,10 @@ has 'body' => (
 
 
 
-override parse ( Int $index, ArrayRef[Str] $input,  ArrayRef[TSQL::AST::SQLFragment] $output ) {
-    return ;
-}
+#override parse ( ScalarRef[Int] $index, ArrayRef[Str] $input) {
+#    my $output = undef;
+#    return $output ;
+#}
 
 }
 
